@@ -49,6 +49,29 @@ class CfsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateAccessCert(self, request):
+        """创建用于访问文件系统的凭证
+
+        :param request: Request instance for CreateAccessCert.
+        :type request: :class:`tencentcloud.cfs.v20190719.models.CreateAccessCertRequest`
+        :rtype: :class:`tencentcloud.cfs.v20190719.models.CreateAccessCertResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateAccessCert", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateAccessCertResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateAutoSnapshotPolicy(self, request):
         """创建定期快照策略
 
@@ -235,7 +258,7 @@ class CfsClient(AbstractClient):
 
 
     def DeleteCfsPGroup(self, request):
-        """本接口（DeleteCfsPGroup）用于删除权限组。
+        """本接口（DeleteCfsPGroup）用于删除权限组，只有未绑定文件系统的权限组才能够被此接口删除。
 
         :param request: Request instance for DeleteCfsPGroup.
         :type request: :class:`tencentcloud.cfs.v20190719.models.DeleteCfsPGroupRequest`
@@ -352,7 +375,7 @@ class CfsClient(AbstractClient):
 
 
     def DeleteUserQuota(self, request):
-        """指定条件删除文件系统配额
+        """指定条件删除文件系统配额（仅部分Turbo实例能使用，若需要调用请提交工单与我们联系）
 
         :param request: Request instance for DeleteUserQuota.
         :type request: :class:`tencentcloud.cfs.v20190719.models.DeleteUserQuotaRequest`
@@ -699,7 +722,7 @@ class CfsClient(AbstractClient):
 
 
     def ModifyFileSystemAutoScaleUpRule(self, request):
-        """用来设置文件系统扩容策略
+        """用来设置文件系统扩容策略，，该接口只支持turbo文件系统
 
         :param request: Request instance for ModifyFileSystemAutoScaleUpRule.
         :type request: :class:`tencentcloud.cfs.v20190719.models.ModifyFileSystemAutoScaleUpRuleRequest`
@@ -722,7 +745,7 @@ class CfsClient(AbstractClient):
 
 
     def ScaleUpFileSystem(self, request):
-        """该接口用于对turbo 文件系统扩容使用
+        """该接口用于对turbo 文件系统扩容使用,该接口只支持扩容不支持缩容。turbo标准型扩容步长是10240GIB，turbo性能型扩容步长是5120GIB
 
         :param request: Request instance for ScaleUpFileSystem.
         :type request: :class:`tencentcloud.cfs.v20190719.models.ScaleUpFileSystemRequest`
@@ -745,7 +768,7 @@ class CfsClient(AbstractClient):
 
 
     def SetUserQuota(self, request):
-        """设置文件系统配额，提供UID/GID的配额设置的接口
+        """设置文件系统配额，提供UID/GID的配额设置的接口（仅部分Turbo实例能使用，若需要调用请提交工单与我们联系）
 
         :param request: Request instance for SetUserQuota.
         :type request: :class:`tencentcloud.cfs.v20190719.models.SetUserQuotaRequest`
