@@ -56,6 +56,9 @@ FAILEDOPERATION_DESCRIBEDOMAINLISTFAILED = 'FailedOperation.DescribeDomainListFa
 # 查询模板操作失败。
 FAILEDOPERATION_DESCRIBETEMPLATEFAILED = 'FailedOperation.DescribeTemplateFailed'
 
+# 当前域名已经不属于预约状态
+FAILEDOPERATION_DESCRIBEUNPREDOMAINDETAILERR = 'FailedOperation.DescribeUnPreDomainDetailErr'
+
 # 域名已过期，不允许操作。
 FAILEDOPERATION_DOMAINEXPIREDUNSUPPORTED = 'FailedOperation.DomainExpiredUnsupported'
 
@@ -278,6 +281,9 @@ INVALIDPARAMETER_TELEPHONEISINVALID = 'InvalidParameter.TelephoneIsInvalid'
 # 仅支持已验证的手机号码，请先在控制台创建后使用。
 INVALIDPARAMETER_TELEPHONEISUNVERIFIED = 'InvalidParameter.TelephoneIsUnverified'
 
+# 模板信息地址错误，请检查后，请重新操作
+INVALIDPARAMETER_TEMPLATEADDRESSINVALID = 'InvalidParameter.TemplateAddressInvalid'
+
 # 域名数量不能超过4000个。
 INVALIDPARAMETER_UPTO4000 = 'InvalidParameter.UpTo4000'
 
@@ -338,6 +344,9 @@ RESOURCENOTFOUND_BIDPRICECONFIG = 'ResourceNotFound.BidPriceConfig'
 # 域名地址有误，请输入正确的域名地址。
 RESOURCENOTFOUND_DOMAINNOTFOUND = 'ResourceNotFound.DomainNotFound'
 
+# 获取数据查找不到。
+RESOURCENOTFOUND_SEARCHINFO = 'ResourceNotFound.SearchInfo'
+
 # 模板信息有误，请输入正确的信息。
 RESOURCENOTFOUND_TEMPLATENOTFOUND = 'ResourceNotFound.TemplateNotFound'
 
